@@ -9,9 +9,9 @@ use fil_actors_runtime::test_utils::*;
 use fil_actors_runtime::{
     ActorError, Multimap, FIRST_NON_SINGLETON_ADDR, STORAGE_POWER_ACTOR_ADDR, SYSTEM_ACTOR_ADDR,
 };
-use fvm_ipld_encoding::RawBytes;
 use fvm_shared::address::Address;
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 use fvm_shared::{HAMT_BIT_WIDTH, METHOD_CONSTRUCTOR};
 use serde::Serialize;
@@ -36,7 +36,7 @@ fn abort_cant_call_exec() {
 
     let err =
         exec_and_verify(&mut rt, *POWER_ACTOR_CODE_ID, &"").expect_err("Exec should have failed");
-    assert_eq!(err.exit_code(), ExitCode::USR_FORBIDDEN);
+    assert_eq!(err.exit_code(), ExitCode::ErrForbidden);
 }
 
 #[test]
@@ -61,9 +61,7 @@ fn create_2_payment_channels() {
         let expected_id_addr = Address::new_id(expected_id);
         rt.expect_create_actor(*PAYCH_ACTOR_CODE_ID, expected_id);
 
-        let fake_params = ConstructorParams {
-            network_name: String::from("fake_param"),
-        };
+        let fake_params = ConstructorParams { network_name: String::from("fake_param") };
 
         // expect anne creating a payment channel to trigger a send to the payment channels constructor
         let balance = TokenAmount::from(100u8);
@@ -74,19 +72,13 @@ fn create_2_payment_channels() {
             RawBytes::serialize(&fake_params).unwrap(),
             balance,
             RawBytes::default(),
-            ExitCode::OK,
+            ExitCode::Ok,
         );
 
         let exec_ret = exec_and_verify(&mut rt, *PAYCH_ACTOR_CODE_ID, &fake_params).unwrap();
         let exec_ret: ExecReturn = RawBytes::deserialize(&exec_ret).unwrap();
-        assert_eq!(
-            unique_address, exec_ret.robust_address,
-            "Robust Address does not match"
-        );
-        assert_eq!(
-            expected_id_addr, exec_ret.id_address,
-            "Id address does not match"
-        );
+        assert_eq!(unique_address, exec_ret.robust_address, "Robust Address does not match");
+        assert_eq!(expected_id_addr, exec_ret.id_address, "Id address does not match");
 
         let state: State = rt.get_state().unwrap();
         let returned_address = state
@@ -113,9 +105,7 @@ fn create_storage_miner() {
     let expected_id_addr = Address::new_id(expected_id);
     rt.expect_create_actor(*MINER_ACTOR_CODE_ID, expected_id);
 
-    let fake_params = ConstructorParams {
-        network_name: String::from("fake_param"),
-    };
+    let fake_params = ConstructorParams { network_name: String::from("fake_param") };
 
     rt.expect_send(
         expected_id_addr,
@@ -123,7 +113,7 @@ fn create_storage_miner() {
         RawBytes::serialize(&fake_params).unwrap(),
         0u8.into(),
         RawBytes::default(),
-        ExitCode::OK,
+        ExitCode::Ok,
     );
 
     let exec_ret = exec_and_verify(&mut rt, *MINER_ACTOR_CODE_ID, &fake_params).unwrap();
@@ -144,10 +134,7 @@ fn create_storage_miner() {
     let unknown_addr = Address::new_actor(b"flurbo");
 
     let returned_address = state.resolve_address(&rt.store, &unknown_addr).unwrap();
-    assert_eq!(
-        returned_address, None,
-        "Addresses should have not been found"
-    );
+    assert_eq!(returned_address, None, "Addresses should have not been found");
 }
 
 #[test]
@@ -168,9 +155,7 @@ fn create_multisig_actor() {
     let expected_id_addr = Address::new_id(expected_id);
     rt.expect_create_actor(*MULTISIG_ACTOR_CODE_ID, expected_id);
 
-    let fake_params = ConstructorParams {
-        network_name: String::from("fake_param"),
-    };
+    let fake_params = ConstructorParams { network_name: String::from("fake_param") };
     // Expect a send to the multisig actor constructor
     rt.expect_send(
         expected_id_addr,
@@ -178,20 +163,14 @@ fn create_multisig_actor() {
         RawBytes::serialize(&fake_params).unwrap(),
         0u8.into(),
         RawBytes::default(),
-        ExitCode::OK,
+        ExitCode::Ok,
     );
 
     // Return should have been successful. Check the returned addresses
     let exec_ret = exec_and_verify(&mut rt, *MULTISIG_ACTOR_CODE_ID, &fake_params).unwrap();
     let exec_ret: ExecReturn = RawBytes::deserialize(&exec_ret).unwrap();
-    assert_eq!(
-        unique_address, exec_ret.robust_address,
-        "Robust address does not macth"
-    );
-    assert_eq!(
-        expected_id_addr, exec_ret.id_address,
-        "Id address does not match"
-    );
+    assert_eq!(unique_address, exec_ret.robust_address, "Robust address does not macth");
+    assert_eq!(expected_id_addr, exec_ret.id_address, "Id address does not match");
 }
 
 #[test]
@@ -211,16 +190,14 @@ fn sending_constructor_failure() {
     let expected_id_addr = Address::new_id(expected_id);
     rt.expect_create_actor(*MINER_ACTOR_CODE_ID, expected_id);
 
-    let fake_params = ConstructorParams {
-        network_name: String::from("fake_param"),
-    };
+    let fake_params = ConstructorParams { network_name: String::from("fake_param") };
     rt.expect_send(
         expected_id_addr,
         METHOD_CONSTRUCTOR,
         RawBytes::serialize(&fake_params).unwrap(),
         0u8.into(),
         RawBytes::default(),
-        ExitCode::USR_ILLEGAL_STATE,
+        ExitCode::ErrIllegalState,
     );
 
     let error = exec_and_verify(&mut rt, *MINER_ACTOR_CODE_ID, &fake_params)
@@ -230,27 +207,21 @@ fn sending_constructor_failure() {
 
     assert_eq!(
         error_exit_code,
-        ExitCode::USR_ILLEGAL_STATE,
-        "Exit Code that is returned is not USR_ILLEGAL_STATE"
+        ExitCode::ErrIllegalState,
+        "Exit Code that is returned is not ErrIllegalState"
     );
 
     let state: State = rt.get_state().unwrap();
 
     let returned_address = state.resolve_address(&rt.store, &unique_address).unwrap();
-    assert_eq!(
-        returned_address, None,
-        "Addresses should have not been found"
-    );
+    assert_eq!(returned_address, None, "Addresses should have not been found");
 }
 
 fn construct_and_verify(rt: &mut MockRuntime) {
     rt.expect_validate_caller_addr(vec![*SYSTEM_ACTOR_ADDR]);
-    let params = ConstructorParams {
-        network_name: "mock".to_string(),
-    };
-    let ret = rt
-        .call::<InitActor>(METHOD_CONSTRUCTOR, &RawBytes::serialize(&params).unwrap())
-        .unwrap();
+    let params = ConstructorParams { network_name: "mock".to_string() };
+    let ret =
+        rt.call::<InitActor>(METHOD_CONSTRUCTOR, &RawBytes::serialize(&params).unwrap()).unwrap();
 
     assert_eq!(RawBytes::default(), ret);
     rt.verify();
@@ -258,9 +229,8 @@ fn construct_and_verify(rt: &mut MockRuntime) {
     let state_data: State = rt.get_state().unwrap();
 
     // Gets the Result(CID)
-    let empty_map = Multimap::from_root(&rt.store, &state_data.address_map, HAMT_BIT_WIDTH, 3)
-        .unwrap()
-        .root();
+    let empty_map =
+        Multimap::from_root(&rt.store, &state_data.address_map, HAMT_BIT_WIDTH, 3).unwrap().root();
 
     assert_eq!(empty_map.unwrap(), state_data.address_map);
     assert_eq!(FIRST_NON_SINGLETON_ADDR, state_data.next_id);
@@ -276,15 +246,11 @@ where
     S: Serialize,
 {
     rt.expect_validate_caller_any();
-    let exec_params = ExecParams {
-        code_cid: code_id,
-        constructor_params: RawBytes::serialize(params).unwrap(),
-    };
+    let exec_params =
+        ExecParams { code_cid: code_id, constructor_params: RawBytes::serialize(params).unwrap() };
 
-    let ret = rt.call::<InitActor>(
-        Method::Exec as u64,
-        &RawBytes::serialize(&exec_params).unwrap(),
-    );
+    let ret =
+        rt.call::<InitActor>(Method::Exec as u64, &RawBytes::serialize(&exec_params).unwrap());
 
     rt.verify();
     ret
